import React, { useCallback, useState, useEffect } from "react";
import { Pagination, Grid, Segment, Loader, Table } from "semantic-ui-react";
import { useGraphQuery } from "../stores";
const renderPlaceholder = (index) => {
    return (React.createElement(Table.Row, { key: `loader-${index}` },
        React.createElement(Table.Cell, { width: "16" },
            React.createElement(Loader, { active: true, size: "small", inline: "centered" }))));
};
export const EntityTable = props => {
    const { entity, limit = 20, renderBodyRow, ...tableProps } = props;
    const [offset, setOffset] = useState(0);
    const [page, setPage] = useState(1);
    const { send: findCount, response: count } = useGraphQuery({
        entity,
        method: "findCount"
    });
    const { send: find, response = [], loading } = useGraphQuery({
        entity,
        method: "find",
        args: [
            {},
            {
                limit,
                offset
            }
        ]
    }, [entity, limit, offset]);
    const onPageChange = useCallback((_, { activePage }) => {
        const p = activePage;
        setPage(p);
        setOffset((p - 1) * limit);
    }, [limit]);
    useEffect(() => {
        const cancel = findCount();
        return cancel;
    }, [entity]);
    useEffect(() => {
        const cancel = find();
        return cancel;
    }, [page, entity]);
    return (React.createElement(Segment, { padded: true },
        React.createElement(Table, Object.assign({}, tableProps, { tableData: response.length ? response : new Array(limit), renderBodyRow: (data, index) => {
                if (loading && !response.length) {
                    return renderPlaceholder(index);
                }
                if (renderBodyRow) {
                    return renderBodyRow(data, index);
                }
                return null;
            } })),
        React.createElement(Grid, { centered: true, padded: true },
            React.createElement(Pagination, { disabled: !count, defaultActivePage: page, totalPages: count ? Math.ceil(count / limit) : 1, onPageChange: onPageChange }))));
};
